#
# spec file for package php-uuid
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name    uuid

%define flavor php8%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%endif
%if 0%{?suse_version} <= 1500
%define php_extdir  %(%{__php_config} --extension-dir)
%define php_cfgdir  %{_sysconfdir}/%{php_name}/conf.d
%endif

Name:           %{php_name}-%{pkg_name}
Version:        1.2.0
Release:        2.8
Summary:        PHP UUID support functions
License:        LGPL-2.1-only
Group:          Productivity/Networking/Web/Servers
URL:            https://pecl.php.net/%{pkg_name}
Source0:        https://pecl.php.net/get/%{pkg_name}-%{version}.tgz
Source1:        php-%{pkg_name}-rpmlintrc
BuildRequires:  libuuid-devel
BuildRequires:  %{php_name}-devel
Provides:       php-%{pkg_name} = %{version}
Obsoletes:      php-%{pkg_name} < %{version}
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}

%description
This extension provides functions to generate and analyse
universally unique identifiers (UUIDs).

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%{__phpize}
%configure
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{php_cfgdir}
cat > %{buildroot}%{php_cfgdir}/%{pkg_name}.ini <<EOF
; comment out next line to disable %{pkg_name} extension in php
extension = %{pkg_name}.so
EOF

%check
%make_build PHP_EXECUTABLE=%{__php} NO_INTERACTION=1 test

%files
%license LICENSE
%config(noreplace) %{php_cfgdir}/%{pkg_name}.ini
%{php_extdir}/%{pkg_name}.so

%changelog
* Sat Dec 10 2022 Arjen de Korte <suse+build@de-korte.org>
- Remove php7 build for Tumbleweed (PHP 7.4 has reached EOL)
* Wed Feb 17 2021 Arjen de Korte <suse+build@de-korte.org>
- Use _multibuild to also build for php8
- Use php_cfgdir and php_extdir macros to determine location of files
- Run unit tests
* Wed Oct  7 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Upgraded to version 1.2.0
  * raise warnings on bad input value with PHP 7
  * promote warnings to ValueError with PHP 8
  * add type hinting with PHP 8
  * fix bug #66982 uuid_mac checks wrong bit/byte for valid MAC address
* Fri Nov 29 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Upgraded to version 1.1.0
  * add uuid_generate_md5 and uuid_generate_sha1 functions
- Upgraded to version 1.0.5
  * add missing constant UUID_VARIANT_NCS
* Thu Mar 30 2017 jweberhofer@weberhofer.at
- added license to package
* Tue Jan 17 2017 jweberhofer@weberhofer.at
- build PHP7 package
- cleaned up spec
- provides php-uuid symbol
* Tue Jan 12 2016 pgajdos@suse.com
- updated to 1.0.4
* Sun Jul 29 2012 crrodriguez@opensuse.org
- Fix build with newer PHP
* Sun Aug 16 2009 crrodriguez@suse.de
- use new versioning macros if possible
* Wed Apr  2 2008 crrodriguez@suse.de
- update to version 1.0.2
* Wed Mar 26 2008 crrodriguez@suse.de
- update to version 1.0.1, only non-linux specific changes
* Wed Nov 15 2006 soporte@onfocus.cl
- very first build
